(* ::Package:: *)

(* ::Title:: *)
(*One-Region World: Consumption vs. Utility Maximization*)


(* ::Subsubtitle:: *)
(*Mathematica 8*)
(*Version 0.1 February 2014*)


(* ::Subsubsection:: *)
(*Definitions*)


ClearAll[acc,USshare,eUSA1,eUSA2,eUSAstar,estar,\[Rho],\[Rho]\[Rho],g,gg,RayParamC,vn,pi,pc,vl,vc,qn,qk,c1a,c1b,c2a,c2b,c3a,c3b,c4a,c4b,c5a,c5b,c6a,c6b,c7a,c7b,c7c,c7d,outputC0];
acc=15; (* accuracy level *)
Off[NMaximize::incst];


(* ::Text:: *)
(*Emissions*)


USshare=Round[100*EUSA0/EW0]/100.;{eUSA1,eUSA2,eUSAstar}=USshare*{EW1/NUSA1,EW2/NUSA2,EWstar/NUSA2}*10^6;
estar=eUSAstar;


(* ::Text:: *)
(*Growth factors*)


\[Rho]annum=0.00;
\[Rho]=(1+\[Rho]annum)^25-1;
\[Rho]\[Rho]=1+\[Rho];
g=(1+\[Rho])^(1/(\[Alpha]c+\[Alpha]l+\[Alpha]n))-1;
gg=1+g;


(* ::Text:: *)
(*Steady-state ray*)


RayParamC={
	vn = \[Delta]n/k3,
	pi = \[Delta]k/k2,
	pc = (k4(1-\[Delta]k*\[Theta]k)-(1-\[Delta]k))/(k2*k4*\[Theta]k),
	vc = (k4-(1-\[Delta]n))/(k4*k3)*\[Theta]c/\[Theta]n,
	qn = (k3*(k4-1))/(k3*vc+\[Delta]n),
	qk = ((k2*k4*\[Theta]k)/(k4-(1-\[Delta]k))*k1*vc^\[Theta]c)^(1/(1-\[Theta]k))*qn}; 


(* ::Subsubsection:: *)
(*Constraints*)


{propxl1,propxl2,propxl3}={0.6459896271234655,0.6644002463858095,0.6605645757646765};(* The fraction of time devoted to leisure equals the values obtained in Scenario 1 under no growth *)

c1a=c1-\[CapitalLambda]C;
c1b=c2-\[CapitalLambda]C;
c2a=(1-\[Delta]k)*SkUSA0+k2*i1-Sk1;
c2b=(1-\[Delta]k)*Sk1+k2*i2-Sk2;
c3a=(1-\[Delta]n)*SnUSA0+k3*xn1-Sn1;
c3b=(1-\[Delta]n)*Sn1+k3*xn2-Sn2;
c4a=(1-propxl1)*\[Xi]*xeUSA0-xe1-xn1-xc1;
c4b=(1-propxl2)*\[Xi]*xe1-xe2-xn2-xc2;
c5a=k1 xc1^\[Theta]c* Sk1^\[Theta]k*Sn1^\[Theta]n*eUSA1^\[Theta]e*Sm1^\[Theta]m-c1-i1;
c5b=k1 xc2^\[Theta]c* Sk2^\[Theta]k*Sn2^\[Theta]n*eUSA2^\[Theta]e*Sm2^\[Theta]m-c2-i2;
c6a=qk* xe2-Sk2;
c6b=qn* xe2-Sn2;
c7a=c3-\[CapitalLambda]C;
c7b=qn*xe2-Sn3;
c7c=pc*qk*xe2-c3;


(* ::Subsubsection:: *)
(*Optimization Program*)


outputC0=
Part[
	NMaximize[{\[CapitalLambda]C,
		c1a== 0&&c1b>= 0&&
		c2a>= 0&&c2b>= 0&&
		c3a>= 0&&c3b>= 0&&
		c4a>= 0&&c4b>= 0&&
		c5a>= 0&&c5b>= 0&&
		c6a== 0&&c6b== 0&& 
		c7a==0&&c7b==  0&&
		c7c== 0,
		Sk1>0&&Sk2>0&&Sn1>0&&Sn2>0&&i1>0&&i2>0&&c1>0&&c2>0&&
		xc1>0&&xe1>0&&xn1>0&&xc2>0&&xe2>0&&xn2>0&&
		\[CapitalLambda]C>0&& c3>0 &&Sn3>0 },
	{Sk1,Sk2,Sn1,Sn2,
	i1,i2,c1,c2,
	xc1,xe1,xn1,
	xc2,xe2,xn2,
	\[CapitalLambda]C,c3,Sn3},
	Method->{"SimulatedAnnealing","Tolerance"->10^(-6),"PerturbationScale"->0.05},MaxIterations->2000],
2];

Module[{txc3=vc*qn*xe2/.outputC0,txn3=vn*qn*xe2/.outputC0,txe3=xe2/.outputC0,tSk3=qk*xe2/.outputC0,ti3=pi*Sk2/.outputC0,tx1=\[Xi]*xeUSA0/.outputC0,tx2=\[Xi]*xe1/.outputC0,tx3=\[Xi]*xe2/.outputC0},
		outputC0=Flatten[Append[outputC0,{xl1-> propxl1*tx1,xl2-> propxl2*tx2,xl3-> propxl3*tx3,xc3-> txc3,xn3-> txn3,xe3-> txe3,Sk3-> tSk3,i3-> ti3,x1-> tx1,x2-> tx2,x3-> tx3}]]];


(* ::Subsubsection:: *)
(*Tests*)


If[comparison==0,
	Print["TESTS"];
	Print["Constraints evaluated at the solution"];
	primalconstC0=Round[({
		{c1a,c1b},
		{c2a,c2b},
		{c3a,c3b},
		{c4a,c4b},
		{c5a,c5b},
		{c6a,c6b},
		{c7a,c7b,c7c}}
		/.outputC0)*10^5]/10.^5;
		tempfunc[x_,y_]:=Flatten[{x,y}];
	Print[MapThread[tempfunc,{{"(1):","(2):","(3):","(4):","(5):","(6):","(7):"},primalconstC0}]//TableForm];
	ClearAll[tempfunc]
,True]


(* ::Subsubsection:: *)
(*Utility Path*)


u1C0= fu[c1,xl1,Sn1,Sm2]/.outputC0;
u2C0= fu[c2,xl2,Sn2,Sm2]/.outputC0;
u3C0= fu[c3,xl3,Sn3,Smstar]/.outputC0;
u4C0= u3C0;

upathlineC0=ListLinePlot[
			{1,u1C0/uUSA0,u2C0/uUSA0,u3C0/uUSA0,u4C0/uUSA0,u4C0/uUSA0},
			AxesLabel-> {"t","\!\(\*SubscriptBox[\(u\), \(t\)]\)/\!\(\*SubscriptBox[\(u\), \(0\)]\)"},AxesStyle->Directive[20]
			,DataRange->{0,5},PlotMarkers->{Automatic,12},AxesOrigin->{0,0},PlotStyle->{AbsoluteThickness[2]},AspectRatio-> 0.5];

u0line=Graphics[{Black,Dashing[Tiny],Line[{{0,1},{5,1}}],Text["year 2010=1",{4.65,1.1}]}];


(* ::Subsubsection:: *)
(*Economic Variables along the Optimal Path*)


(* ::Text:: *)
(*Economics variables (in 2010-dollars)*)


stockflowsC0=
	Grid[
	SetAccuracy[{
		{Column[{"ECONOMIC VARIABLES","CONSUMPTION-ONLY MAXIMIZATION PROGRAM", "(Thoushands of 2010$ per capita, except for Labor in Education -in efficiency units)"},Alignment->Center],SpanFromLeft},
		{"Gen.", 
			Column[{"Utility","","\!\(\* StyleBox[SubscriptBox[\"u\", \"t\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Stock of","Knowledge","\!\(\* StyleBox[SubsuperscriptBox[\"S\", \"t\", \"n\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Stock of","Physical Capital","\!\(\* StyleBox[SubsuperscriptBox[\"S\", \"t\", \"k\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Labor in","Education","\!\(\* StyleBox[SubsuperscriptBox[\"x\", \"t\", \"e\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Consumption","","\!\(\* StyleBox[SubscriptBox[\"c\", \"t\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Investment","","\!\(\* StyleBox[SubscriptBox[\"i\", \"t\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center]},
		{"0",uUSA0,SnUSA0, SkUSA0,xeUSA0,cUSA0,iUSA0},
		{"1",u1C0,Sn1,Sk1,xe1,c1,i1},
		{"2",u2C0,Sn2,Sk2,xe2,c2,i2},
		{"3",u3C0,Sn3,Sk3,xe3,c3,i3},
		{"4",u3C0,Sn3,Sk3,xe3,c3,i3}}/.outputC0
	,4],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None,None,None,None,None,Gray,LightGray,None}}];


(* ::Text:: *)
(*Economic variables (relative to reference-year)*)


stockflowsC0R=
	Grid[
	SetAccuracy[{
		{Column[{"ECONOMIC VARIABLES","CONSUMPTION-ONLY MAXIMIZATION PROGRAM","(realative to reference-year values)"},Alignment-> Center],SpanFromLeft},
		{"Gen.",
			Column[{"Utility","","\!\(\* StyleBox[SubscriptBox[\"u\", \"t\"],\nFontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[ StyleBox[\"u\",\nFontSlant->\"Italic\"], \"0\"]\)"},Alignment->Center],
			Column[{"Stock of","Knowledge","\!\(\* StyleBox[SubsuperscriptBox[\"S\", \"t\", \"n\"],\nFontSlant->\"Italic\"]\)/\!\(\* StyleBox[SubsuperscriptBox[\"S\", StyleBox[\"0\",\nFontSlant->\"Plain\"], \"n\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Stock of","Physical Capital","\!\(\* StyleBox[SubsuperscriptBox[\"S\", \"t\", \"k\"],\nFontSlant->\"Italic\"]\)/\!\(\* StyleBox[SubsuperscriptBox[\"S\", StyleBox[\"0\",\nFontSlant->\"Plain\"], \"k\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Labor in","Education","\!\(\* StyleBox[SubsuperscriptBox[\"x\", \"t\", \"e\"],\nFontSlant->\"Italic\"]\)/\!\(\* StyleBox[SubsuperscriptBox[\"x\", StyleBox[\"0\",\nFontSlant->\"Plain\"], \"e\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Consumption","\!\(\* StyleBox[SubscriptBox[\"c\", \"t\"],\nFontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[StyleBox[\"c\",\nFontSlant->\"Italic\"], \"0\"]\)"},Alignment->Center],
			Column[{"Investment","\!\(\* StyleBox[SubscriptBox[\"i\", \"t\"],\nFontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[ StyleBox[\"i\",\nFontSlant->\"Italic\"], \"0\"]\)"},Alignment->Center]},		
		{"0",uUSA0/uUSA0,SnUSA0/SnUSA0, SkUSA0/SkUSA0,xeUSA0/xeUSA0,cUSA0/cUSA0,iUSA0/iUSA0},
		{"1",u1C0/uUSA0,Sn1/SnUSA0,Sk1/SkUSA0,xe1/xeUSA0,c1/cUSA0,i1/iUSA0},
		{"2",u2C0/uUSA0,Sn2/SnUSA0,Sk2/SkUSA0,xe2/xeUSA0,c2/cUSA0,i2/iUSA0},
		{"3",u3C0/uUSA0,Sn3/SnUSA0,Sk3/SkUSA0,xe3/xeUSA0,c3/cUSA0,i3/iUSA0},
		{"4",u3C0/uUSA0,Sn3/SnUSA0,Sk3/SkUSA0,xe3/xeUSA0,c3/cUSA0,i3/iUSA0}}/.outputC0
	,4],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None,None,None,None,None,Gray,LightGray,None}}];


(* ::Subsubsection:: *)
(*Labor Allocation along the Optimal Path*)


(* ::Text:: *)
(*Labor allocation (in efficiency units)*)


laborC0=
	Grid[
	SetAccuracy[{
		{Column[{"LABOR ALLOCATION","CONSUMPTION-ONLY MAXIMIZATION PROGRAM", "(in efficiency units)"},Alignment->Center],SpanFromLeft},
		{"Gen.",
			Column[{"Total","\!\(\* StyleBox[SubscriptBox[\"x\", \"t\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Leisure","\!\(\*StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"l\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Consumption","\!\(\*StyleBox[SubsuperscriptBox[StyleBox[\"x\", \"Text\"], \"t\", \"c\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Education","\!\(\*StyleBox[SubsuperscriptBox[StyleBox[\"x\", \"Text\"], \"t\", \"e\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Knowledge","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"n\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center]},
		{"0",xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0},
		{"1",{x1,xl1,xc1,xe1,xn1}/.outputC0}//Flatten,
		{"2",{x2,xl2,xc2,xe2,xn2}/.outputC0}//Flatten,
		{"3",{x3,xl3,xc3,xe3,xn3}/.outputC0}//Flatten,
		{"4",gg{x3,xl3,xc3,xe3,xn3}/.outputC0}//Flatten}
	,5],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None}}];


(* ::Text:: *)
(*Labor allocation (as fraction of total labor-leisure)*)


laborC0R=
	Grid[
	SetAccuracy[
		{{Column[{"LABOR ALLOCATION","CONSUMPTION-ONLY MAXIMIZATION PROGRAM", "(Fraction of total labor-leisure available)"},Alignment->Center],SpanFromLeft},
		{"Gen.",
			Column[{"Total","\!\(\* StyleBox[SubscriptBox[\"x\", \"t\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Leisure","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"l\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Consumption","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"c\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Education","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"e\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Knowledge","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"n\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center]},
		{"0",MapThread[Divide,{{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0},{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"1",MapThread[Divide,{{x1,xl1,xc1,xe1,xn1}/.outputC0,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"2",MapThread[Divide,{{x2,xl2,xc2,xe2,xn2}/.outputC0,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"3",MapThread[Divide,{{x3,xl3,xc3,xe3,xn3}/.outputC0,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"4",MapThread[Divide,{gg*{x3,xl3,xc3,xe3,xn3}/.outputC0,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten}
	,5],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None}}];


If[comparison==1,
	Get[FileNameJoin[{NotebookDirectory[],"OneRegionWorldC v01.m"}]]]


(* ::Text:: *)
(*\[Copyright] Llavador, Roemer, Silvestre 2014*)
