(* ::Package:: *)

(* ::Subtitle:: *)
(*GENERATED DATA for LRS-BOOK*)


(* ::Subsubsection:: *)
(*Population*)


(* ::Text:: *)
(*Total world (NW) and relative populations*)


NW0=N0 = NN0+NS0;         (* pop World Gen 0 -thoushands of persons- *)
NW1=N1 = NN1+NS1;         (* pop World Gen 1 -thoushands of persons- *)
NW2=N2 = NWstar=NN2+NS2;  (* pop World Gen 2 -thoushands of persons- *)
nN0=n[1,0] = NN0/NW0;         (* relative population in North Gen 0 *)
nN1=n[1,1] = NN1/NW1;         (* relative population in North Gen 0 *)
nN2=n[1,2] = nNstar=NN2/NW2;  (* relative population in North Gen 0 *)
nS0=n[2,0] = NS0/NW0;         (* relative population in North Gen 0 *)
nS1=n[2,1] = NS1/NW1;         (* relative population in North Gen 0 *)
nS2=n[2,2] = nSstar=NS2/NW2;  (* relative population in North Gen 0 *)


(* ::Subsubsection:: *)
(*Emissions/Concentration (path)*)


EW0          = EN0+ES0;             (* current annual World CO2 emissions in GtC *)
eW0=e0       = EW0/NW0*10^6;        (* current annual world CO2 emissions per capita in tC per capita *)
eN0=e[1,0]   = EN0/NN0*10^6;        (* current annual CO2 emissions per capita by North in tC per capita*)
eS0=e[2,0]   = ES0/NS0*10^6;        (* current annual CO2 emissions per capita by South tC per capita *)
eUSA0        = EUSA0/NUSA0*10^6;    (* current US CO2 emissions per capita in tC per capita*)
eChina0      = EChina0/NChina0*10^6; (* current annual China CO2 emissions per capita in tC per capita*)
eW1=e1       = EW1/NW1*10^6;        (* world annual CO2 emissions per capita by Gen. 1 in tC  per capita *)
eW2=e2       = EW2/NW2*10^6;        (* world annual CO2 emissions per capita by Gen. 2 in tC  per capita *)
eWstar       = Estar/NWstar*10^6;   (* world annual CO2 emissions per capita at steady state in tC  per capita *)


(* ::Subsubsection:: *)
(*Utility-Welfare*)


fu[vc_,vxl_,vSn_,vSm_]:=vc^\[Alpha]c * vxl^\[Alpha]l * vSn^\[Alpha]n * (Smhat-vSm)^\[Alpha]m; (* utility function *)
\[Alpha]c = 1/(1+\[Alpha]l\[Alpha]c+\[Alpha]n\[Alpha]c+\[Alpha]m\[Alpha]c); (* utility elasticity of consumption *)
\[Alpha]l = \[Alpha]l\[Alpha]c*\[Alpha]c;              (* utility elasticity of leisure *)
\[Alpha]n = \[Alpha]n\[Alpha]c*\[Alpha]c;              (* utility elasticity of knowledge *)
\[Alpha]m = \[Alpha]m\[Alpha]c*\[Alpha]c;              (* utility elasticity of environmental quality *)


(* ::Subsubsection:: *)
(*Initial values: YEAR 0 DATA NORTH and USA*)


xlN0=xlUSA0=xl[1,0]    = xUSA0*xlxUSA0;              (* efficiency units in leisure *)
xcxLN0=xcxLUSA0        = 1-xexLUSA0-xnxLUSA0;        (* fraction of working time in production *)
xcN0=xcUSA0=xc[1,0]    = (xUSA0-xlUSA0)*xcxLUSA0;    (* labor time in production in efficiency units *)
xeN0=xeUSA0=xe[1,0]    = (xUSA0-xlUSA0)*xexLUSA0;    (* labor time in eudcation, in efficiency units *)
xnN0=xnUSA0=xn[1,0]    = (xUSA0-xlUSA0)*xnxLUSA0;    (* labor time in production of knowledge in efficiency units *)
uN0=uUSA0              = fu[cUSA0,xlUSA0,SnUSA0,Sm0];(* Initial utility level for benchmark year 0 *)
fN0=fUSA0              = cUSA0+iUSA0;                (* Initial output for benchmark year 0 *)


(* ::Subsubsection:: *)
(*Initial values:  YEAR 0 DATA SOUTH and CHINA*)


SnS0=Sn[2,0]   = 0.7762+6.1*\[Lambda]annum;   (* stock on knowledge in China, in thousands of $ per capita *)
                                        (* Empirical relation obtained from data 1980-2005 by PIM *)
xlS0=xl[2,0]   = xS0*xlxS0;             (* efficiency units in leisure *)
xcxLS0         = 1-xexLS0-xnxLS0;       (* fraction of working time in production of commodity *)         
xcS0=xc[2,0]   = (xS0-xlS0)*xcxLS0;     (* efficiency units in production of commodity *)
xeS0=xe[2,0]   = (xS0-xlS0)*xexLS0;     (* efficiency units in education*)
xnS0=xn[2,0]   = (xS0-xlS0)*xnxLS0;     (* efficiency units in production of knowledge *)
uS0            = fu[cS0,xlS0,SnS0,Sm0]; (* Initial utility in South Year 0 *)
fS0            = cS0+iS0;               (* Initial output in South Year 0 *)


(* ::Subsubsection:: *)
(*Production*)


(* ::Text:: *)
(*Production of consumption good (CRS in c, k, and n)*)


f[vxc_,vSk_,vSn_,ve_,vSm_]:=k1 * vxc^\[Theta]c * vSk^\[Theta]k * vSn^\[Theta]n * ve^\[Theta]e * vSm^\[Theta]m; (* production function of commodity good *)
k1 = yUSA0/(xcUSA0^\[Theta]c*SkUSA0^\[Theta]k*SnUSA0^\[Theta]n*eUSA0^\[Theta]e*Sm0^\[Theta]m); (* constant calibrated to USA in year 2005 *)


(* ::Subsubsection:: *)
(*Physical capital*)


\[Delta]k = 1-(1-\[Delta]kannum)^25;   (* generational rate of depreciation of knowledge *)
k2 = \[Delta]k/(1-(1-\[Delta]kannum)); (* constant *)


(* ::Subsubsection:: *)
(*Knowledge*)


\[Delta]n  = 1-(1-\[Delta]nannum)^25;       (* generational rate of depreciation of knowledge *)
k3  = wbar*\[Delta]n/(1-(1-\[Delta]nannum));(* constant *)
k3d = \[Lambda]annum*k3;              (* constant *)


(* ::Subsubsection:: *)
(*Education function*)


\[Xi]=k4 = 1/xexannum*(1+sannum)^25; (* constant *)
