(* ::Package:: *)

(* ::Subtitle:: *)
(*DATA VALUES for LRS-BOOK in 2010-int.$*)


(* ::Subsubsection:: *)
(*Population*)


(* Source: Population Division of the Department of Economic and Social Affairs of the United Nations
Secretariat, World Population Prospects: The 2012 Revision, http://esa.un.org/unpd/wpp/index.htm *)
NN0            =1240934.72; (* pop North Gen 0=2010 -thoushands of persons- *)
NN1            =1278337.58; (* pop North Gen 1=avg .2011-2035 -thoushands of persons- *)
NN2=NNstar     =1295939.58; (* pop North Gen 2=avg .2036-2100 -thoushands of persons- *)
NS0            =5675248.76; (* pop South Gen 0=2010 -thoushands of persons- *)
NS1            =6635766.48; (* pop South Gen 1=avg .2011-2035 -thoushands of persons- *)
NS2=NSstar     =8790832.87; (* pop South Gen 2=avg .2036-2100 -thoushands of persons- *)
NUSA0=N0USA    = 312247.12; (* pop USA Gen 0=2010 -thoushands of persons- *)
NUSA1          = 345121.85; (* pop USA Gen 1=avg .2011-2035 -thoushands of persons- *)
NUSA2=NUSAstar = 426332.53; (* pop USA Gen 2=avg .2036-2100 -thoushands of persons- *)
NChina0=N0China=1367405.61; (* pop China Gen 0=2010 -thoushands of persons- *)


(* ::Subsubsection:: *)
(*Emissions/Concentration*)


(* EMISSIONS/CONCENTRATION Gen .0= YEAR-2010 from CAIT 2.0 (WRI, 2013) *)
Sm0     = 390.43;   (* current CO2 concentration in ppm MAGICC *)
EN0     = 3.8615;  (* current annual CO2 emissions by North in GtC *)
ES0     = 5.1809;  (* current annual CO2 emissions by South in GtC *)
EUSA0   = 1.5464;  (* current annual US CO2 emissions in GtC *)
EChina0 = 2.4261;  (* current annual China CO2 emissions in GtC *)
(* EMISSION/CONCENTRATION PATH from MAGICC *)
EW1          = 8.1515;   (* annual World CO2 emissions by Gen. 1 in GtC *)
EW2          = 3.4146;   (* annual World CO2 emissions by Gen. 2 in GtC *)
EWstar=Estar = 1.4679;    (* annual World CO2 emissions steady state in GtC *)
Sm1          = 439.21;   (* CO2 concentration at end of Gen. 1 in ppm *)
Sm2          = 445.63;   (* CO2 concentration at end of Gen. 2 in ppm *)
Smstar       = 444.56;    (* CO2 concentration at steady state in ppm *)
(* Reference data *)
Sm1850   = 280.;   (* Pre-industrial CO2 concentration in ppm *)
\[Sigma]        = 3.;     (* Climate sensitivity *)
fSm[v\[Tau]_] = Sm1850/1.16 2^(v\[Tau]/\[Sigma]);  (* Inverse function of the Bern model in ppm of CO2 *)
Smhat    = (fSm[8]+fSm[6])/2;     (* Critical CO2 concentration (average 6\.baC and 8\.baC) in ppm *)


(* ::Subsubsection:: *)
(*Utility/Welfare*)


\[Alpha]l\[Alpha]c = 2.;     (* leisure to consumption ratio *)
\[Alpha]n\[Alpha]c = 0.055;   (* expenditure in knowledge over consumption *)
\[Alpha]m\[Alpha]c = Log[0.94]/(Log[Smhat-fSm[5]]-Log[Smhat-Sm1850]); (* environment to consumption ratio *)


(* ::Subsubsection:: *)
(*Production*)


(* ::Text:: *)
(*Production of consumption good (CRS in c, k and n)*)


\[Theta]c  = 0.67;        (* elasticity labor in production function *)
\[Theta]k  = 0.86*(1-\[Theta]c); (* elasticity physical capital in production function *)
\[Theta]n  = 0.14*(1-\[Theta]c); (* elasticity knowledge in production function *)
\[Theta]e  = 0.0910;       (* elasticity emissions in production function *)
\[Theta]m  = Log[1-0.028]/(Log[fSm[3.4]]-Log[fSm[0]]); (* elasticity environmental stock in production function: 3.4\.ba -> 2.8% loss*)


(* ::Subsubsection:: *)
(*Physical capital*)


\[Delta]kannum = 0.06; (* annual depreciation rate of physical capital *)


(* ::Subsubsection:: *)
(*Knowledge *)


\[Delta]nannum = 0.06; (* annual depreciation rate of knowledge *)
wbar    = 42.56;(* intermediate variable: "wage" of an efficient unit of labor *)
\[Lambda]annum  = 0.01; (* parameter for the diffusion of knowledge *)


(* ::Subsubsection:: *)
(*Education function*)


sannum   = 0.013;  (* average yearly growth rate of the human capital stock *)
xexannum = 1/3.*0.1;  (* share of education in total time = fraction of labor in education * fraction of labor in total time *)


(* ::Subsubsection:: *)
(*Initial values: YEAR 0 DATA USA (calibrated to year 2010)*)


yN0=yUSA0=y[1,0]         = 46.18;       (* GDP per capita in thousands of $ *)
cN0=cUSA0=c[1,0]         = 0.857*yUSA0; (* consumption in thousands of $ per capita *)
iN0=iUSA0=i[1,0]         = 0.143*yUSA0; (* stock on knowledge in thousands of $ per capita *)
xN0=xUSA0=x[1,0]         = 2.17;        (* labor in production in efficiency units *)
xlxN0=xlxUSA0            = 0.67;        (* fraction of total time in leisure *)
xexLN0=xexLUSA0          = 0.10;        (* fraction of working time in education *)
xnxLN0=xnxLUSA0          = 0.05;        (* fraction of working time in production of knowledge *)
SkN0=SkUSA0=Sk[1,0]      = 101.57;       (* stock on physical capital in thousands of $ per capita *)
SnN0=SnUSA0=Sn[1,0]      = 26.95;       (* stock on knowledge in thousands of $ per capita *)


(* ::Subsubsection:: *)
(*Initial values: YEAR 0 DATA CHINA (calibrated to year 2010)*)


yS0=yChina0=y[2,0]       = 8.56;        (* GDP per capita in thousands of $ *)
cS0=cChina0=c[2,0]       = 0.5*yChina0; (* consumption in thousands of $ per capita *)
iS0=iChina0=i[2,0]       = 0.5*yChina0; (* stock on knowledge in thousands of $ per capita *)
xS0=xChina0=x[2,0]       = 1.34;        (* labor in production in efficiency units *)
xlxS0=xlxChina0          = 0.65;        (* fraction of total time in leisure *)
xexLS0=xexLChina0        = 0.06;        (* fraction of working time in education *)
xnxLS0=xnxLChina0        = 0.025;       (* fraction of working time in production of knowledge *)
SkS0=SkChina0=Sk[2,0]    = 34.36;       (* stock on physical capital in thousands of $ per capita *)
(* SnS0=SnChina0 = DEPENDS ON \[Lambda];        (* stock on knowledge in thousands of $ per capita *)*)
