(* ::Package:: *)

(* ::Title:: *)
(*One-Region World*)


(* ::Subsubtitle:: *)
(*Mathematica 8*)
(*Version 0.1 February 2014*)


ClearAll[acc,USshare,eUSA1,eUSA2,eUSAstar,estar,\[Rho],\[Rho]\[Rho],g,gg,RayParam,vn,pi,pc,vl,vc,qn,qk,c1a,c1b,c2a,c2b,c3a,c3b,c4a,c4b,c5a,c5b,c6a,c6b,c7a,c7b,c7c,c7d,output];
acc=15; (* accuracy level *)
Off[NMaximize::incst];


(* ::Text:: *)
(*Emissions*)


Which[
	scenario==1,USshare=Round[100*EUSA0/EW0]/100.;{eUSA1,eUSA2,eUSAstar}=USshare*{EW1/NUSA1,EW2/NUSA2,EWstar/NUSA2}*10^6 ,
	scenario==2,{eUSA1,eUSA2,eUSAstar}={eW1,eW2,eWstar},
	True, Print["Please, choose \!\(\* StyleBox[\"scenario\",\nFontSlant->\"Italic\"]\)=1 or \!\(\* StyleBox[\"scenario\",\nFontSlant->\"Italic\"]\)=2"];Quit[]
];
estar=eUSAstar;


(* ::Text:: *)
(*Growth factors*)


\[Rho]=(1+\[Rho]annum)^25-1;
\[Rho]\[Rho]=1+\[Rho];
g=(1+\[Rho])^(1/(\[Alpha]c+\[Alpha]l+\[Alpha]n))-1;
gg=1+g;


(* ::Text:: *)
(*Steady-state ray*)


RayParam={
	vn = (g + \[Delta]n)/k3,
	pi = (g + \[Delta]k)/k2,
	pc = (1 - (1 - \[Delta]k)/k4)*((1 + g)/(k2*\[Theta]k)) - pi,
	vl = (1 - (1 - \[Delta]n)/k4)*(\[Alpha]l/k3)*(pc/(\[Alpha]c*\[Theta]n*(pc + pi) + \[Alpha]n*pc))*(1 + g), 
	vc = (1 - (1 - \[Delta]n)/k4)*((\[Alpha]c*\[Theta]c)/k3)*((pc + pi)/(\[Alpha]c*\[Theta]n*(pc + pi) + \[Alpha]n*pc))*(1 + g),
	qn = (k4 - (1 + g))/(vl + vn + vc),
	qk = ((k1*vc^\[Theta]c)/(pc + pi))^(1/(\[Theta]c + \[Theta]n))(1 + g)^((\[Theta]k + \[Theta]n)/(\[Theta]c + \[Theta]n))*qn*estar^(\[Theta]e/(\[Theta]n + \[Theta]c))*Smstar^(\[Theta]m/(\[Theta]n + \[Theta]c))}; 


(* ::Subsubsection:: *)
(*Constraints*)


c1a=c1^\[Alpha]c*xl1^\[Alpha]l*Sn1^\[Alpha]n*(Smhat-Sm1)^\[Alpha]m-\[CapitalLambda];
c1b=c2^\[Alpha]c*xl2^\[Alpha]l*Sn2^\[Alpha]n*(Smhat-Sm2)^\[Alpha]m-\[Rho]\[Rho]*\[CapitalLambda];
c2a=(1-\[Delta]k)*SkUSA0+k2*i1-Sk1;
c2b=(1-\[Delta]k)*Sk1+k2*i2-Sk2;
c3a=(1-\[Delta]n)*SnUSA0+k3*xn1-Sn1;
c3b=(1-\[Delta]n)*Sn1+k3*xn2-Sn2;
c4a=\[Xi]*xeUSA0-xe1-xn1-xc1-xl1;
c4b=\[Xi]*xe1-xe2-xn2-xc2-xl2;
c5a=k1*xc1^\[Theta]c*Sk1^\[Theta]k*Sn1^\[Theta]n*eUSA1^\[Theta]e*Sm1^\[Theta]m-c1-i1;
c5b=k1*xc2^\[Theta]c*Sk2^\[Theta]k*Sn2^\[Theta]n*eUSA2^\[Theta]e*Sm2^\[Theta]m-c2-i2;
c6a=qk*xe2-Sk2;
c6b=qn*xe2-Sn2;
c7a=c3^\[Alpha]c*xl3^\[Alpha]l*Sn3^\[Alpha]n*(Smhat-Smstar)^\[Alpha]m-\[Rho]\[Rho]^2*\[CapitalLambda];
c7b=(1+g)*qn*xe2-Sn3;
c7c=pc*qk*xe2-c3;
c7d=vl*qn*xe2-xl3;


(* ::Subsubsection:: *)
(*Optimization Program*)


output=
Part[
	NMaximize[{\[CapitalLambda],
		c1a>= 0&&c1b>= 0&&
		c2a>= 0&&c2b>= 0&&
		c3a>= 0&&c3b>= 0&&
		c4a>= 0&&c4b>= 0&&
		c5a>= 0&&c5b>= 0&&
		c6a== 0&&c6b== 0&& 
		c7a==0&&c7b==  0&&c7c== 0&&c7d==0,
		Sk1>0&&Sk2>0&&Sn1>0&&Sn2>0&&i1>0&&i2>0&&c1>0&&c2>0&&
		xl1>0&&xc1>0&&xe1>0&&xn1>0&&xl2>0&&xc2>0&&xe2>0&&xn2>0&&
		\[CapitalLambda]>0&& c3>0 && xl3>0&&Sn3>0},
		{Sk1,Sk2,Sn1,Sn2,
		i1,i2,c1,c2,
		xl1,xc1,xe1,xn1,
		xl2,xc2,xe2,xn2,
		\[CapitalLambda],c3,xl3,Sn3},
	Method->{"SimulatedAnnealing","Tolerance"->10^(-6),"PerturbationScale"->0.05},MaxIterations->10000],
2];

Module[
	{tx1=(xc1+xl1+xn1+xe1)/.output,tx2=(xc2+xl2+xn2+xe2)/.output,txc3=vc qn xe2/.output,txn3=vn qn xe2/.output,txe3=(1+g)*xe2/.output,tSk3=(1+g)qk xe2/.output,ti3=pi Sk2/.output,txl3= xl3/.output},
	output=Flatten[Append[output,{xc3-> txc3,xn3-> txn3,xe3-> txe3,Sk3-> tSk3,i3-> ti3,x1-> tx1,x2-> tx2,x3-> txl3+txc3+txn3+txe3}]]];


(* ::Subsubsection:: *)
(*Tests*)


Print["TESTS"]
Print["Constraints evaluated at the solution"];
primalconst=Round[({
	{c1a,c1b},
	{c2a,c2b},
	{c3a,c3b},
	{c4a,c4b},
	{c5a,c5b},
	{c6a,c6b},
	{c7a,c7b,c7c,c7d}}
	/.output)*10^5]/10.^5;

	tempfunc[x_,y_]:=Flatten[{x,y}];
Print[MapThread[tempfunc,{{"(1):","(2):","(3):","(4):","(5):","(6):","(7):"},primalconst}]//TableForm];
	ClearAll[tempfunc];


(* ::Subsubsection:: *)
(*Utility Path*)


u1=fu[c1,xl1,Sn1,Sm1]/.output;
u2=fu[c2,xl2,Sn2,Sm2]/.output;
u3=fu[c3,xl3,Sn3,Smstar]/.output;

upathline=ListLinePlot[
			{1,u1/uUSA0,u2/uUSA0,u3/uUSA0,\[Rho]\[Rho]*u3/uUSA0,\[Rho]\[Rho]^2*u3/uUSA0},
			AxesLabel-> {"t","\!\(\*SubscriptBox[\(u\), \(t\)]\)/\!\(\*SubscriptBox[\(u\), \(0\)]\)"},AxesStyle->Directive[20],PlotRange-> {0,Ceiling[\[Rho]\[Rho]^2*u3/uUSA0]},
			DataRange->{0,5},PlotMarkers->{Automatic,12},AxesOrigin->{0,0},PlotStyle->{AbsoluteThickness[2]},AspectRatio-> 0.5];

u0line=Graphics[{Black,Dashing[Tiny],Line[{{0,1},{5,1}}],Text["year 2010=1",{4.65,1.1}]}];


(* ::Subsubsection:: *)
(*Economic Variables along the Optimal Path*)


(* ::Text:: *)
(*Economics variables (in 2010-dollars)*)


stockflows=
	Grid[
	SetAccuracy[{
		{Column[{"ECONOMIC VARIABLES", "Thoushands of 2010$ per capita","(except Labor in Education -in efficiency units-"},Alignment->Center],SpanFromLeft},
		{"Gen.",
			Column[{"Utility","","\!\(\* StyleBox[SubscriptBox[\"u\", \"t\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Stock of","Knowledge","\!\(\* StyleBox[SubsuperscriptBox[\"S\", \"t\", \"n\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Stock of","Physical Capital","\!\(\* StyleBox[SubsuperscriptBox[\"S\", \"t\", \"k\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Labor in","Education","\!\(\* StyleBox[SubsuperscriptBox[\"x\", \"t\", \"e\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Consumption","","\!\(\* StyleBox[SubscriptBox[\"c\", \"t\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Investment","","\!\(\* StyleBox[SubscriptBox[\"i\", \"t\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center]},
		{"0",uUSA0,SnUSA0, SkUSA0,xeUSA0,cUSA0,iUSA0},
		{"1",u1,Sn1,Sk1,xe1,c1,i1},
		{"2",u2,Sn2,Sk2,xe2,c2,i2},
		{"3",u3,Sn3,Sk3,xe3,c3,i3},
		Flatten[{"4",\[Rho]\[Rho] u3,gg{Sn3,Sk3,xe3,c3,i3}}]}/.output
	,4],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None,None,None,None,None,Gray,LightGray,None}}];


(* ::Text:: *)
(*Economic variables (relative to reference-year)*)


stockflowsR=
	Grid[
	SetAccuracy[{
		{Column[{"ECONOMIC VARIABLES", "Realative to the values in the reference-year"},Alignment->Center],SpanFromLeft},
	{"Gen.",
		Column[{"Utility","\!\(\* StyleBox[SubscriptBox[\"u\", \"t\"],\nFontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[ StyleBox[\"u\",\nFontSlant->\"Italic\"], \"0\"]\)"},Alignment->Center],
		Column[{"Stock of","Knowledge","\!\(\* StyleBox[SubsuperscriptBox[\"S\", \"t\", \"n\"],\nFontSlant->\"Italic\"]\)/\!\(\*StyleBox[SubsuperscriptBox[\"S\", StyleBox[\"0\",\nFontSlant->\"Plain\"], \"n\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
		Column[{"Stock of","Physical Capital","\!\(\*StyleBox[SubsuperscriptBox[\"S\", \"t\", \"k\"],\nFontSlant->\"Italic\"]\)/\!\(\*StyleBox[SubsuperscriptBox[\"S\", StyleBox[\"0\",\nFontSlant->\"Plain\"], \"k\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
		Column[{"Labor in","Education","\!\(\*StyleBox[SubsuperscriptBox[\"x\", \"t\", \"e\"],\nFontSlant->\"Italic\"]\)/\!\(\*StyleBox[SubsuperscriptBox[\"x\", StyleBox[\"0\",\nFontSlant->\"Plain\"], \"e\"],\nFontSlant->\"Italic\"]\)"},Alignment->Center],
		Column[{"Consumption","\!\(\*StyleBox[SubscriptBox[\"c\", \"t\"],\nFontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[StyleBox[\"c\",\nFontSlant->\"Italic\"], \"0\"]\)"},Alignment->Center],
		Column[{"Investment","\!\(\*StyleBox[SubscriptBox[\"i\", \"t\"],\nFontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[StyleBox[\"i\",\nFontSlant->\"Italic\"], \"0\"]\)"},Alignment->Center]},
	{"0",uUSA0/uUSA0,SnUSA0/SnUSA0, SkUSA0/SkUSA0,xeUSA0/xeUSA0,cUSA0/cUSA0,iUSA0/iUSA0},
	{"1",u1/uUSA0,Sn1/SnUSA0,Sk1/SkUSA0,xe1/xeUSA0,c1/cUSA0,i1/iUSA0},
	{"2",u2/uUSA0,Sn2/SnUSA0,Sk2/SkUSA0,xe2/xeUSA0,c2/cUSA0,i2/iUSA0},
	{"3",u3/uUSA0,Sn3/SnUSA0,Sk3/SkUSA0,xe3/xeUSA0,c3/cUSA0,i3/iUSA0},
	Flatten[{"4",\[Rho]\[Rho] u3/uUSA0,gg{Sn3/SnUSA0,Sk3/SkUSA0,xe3/xeUSA0,c3/cUSA0,i3/iUSA0}}]}/.output
	,4],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None,None,None,None,None,Gray,LightGray,None}}];


(* ::Subsubsection:: *)
(*Labor Allocation along the Optimal Path*)


(* ::Text:: *)
(*Labor allocation in efficiency units*)


labor=
	Grid[
	SetAccuracy[{
		{Column[{"LABOR ALLOCATION","(in efficiency units)"},Alignment->Center],SpanFromLeft},
		{"Gen.",
			Column[{"Total","\!\(\* StyleBox[SubscriptBox[\"x\", \"t\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Leisure","\!\(\*StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"l\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Consumption","\!\(\*StyleBox[SubsuperscriptBox[StyleBox[\"x\", \"Text\"], \"t\", \"c\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Education","\!\(\*StyleBox[SubsuperscriptBox[StyleBox[\"x\", \"Text\"], \"t\", \"e\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Knowledge","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"n\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center]},
		{"0",xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0},
		{"1",{x1,xl1,xc1,xe1,xn1}/.output}//Flatten,
		{"2",{x2,xl2,xc2,xe2,xn2}/.output}//Flatten,
		{"3",{x3,xl3,xc3,xe3,xn3}/.output}//Flatten,
		{"4",gg{x3,xl3,xc3,xe3,xn3}/.output}//Flatten}
	,5],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None}}];


(* ::Text:: *)
(*Labor allocation as fraction of total labor-leisure*)


laborR=
	Grid[
	SetAccuracy[
		{{Column[{"LABOR ALLOCATION","(Fraction of total labor-leisure available)"},Alignment->Center],SpanFromLeft},
		{"Gen.",
			Column[{"Total","\!\(\* StyleBox[SubscriptBox[\"x\", \"t\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Leisure","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"l\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Consumption","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"c\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Education","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"e\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center],
			Column[{"Knowledge","\!\(\* StyleBox[SubsuperscriptBox[ StyleBox[\"x\", \"Text\"], \"t\", \"n\"], \"Text\",\nFontSlant->\"Italic\"]\)"},Alignment->Center]},
		{"0",MapThread[Divide,{{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0},{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"1",MapThread[Divide,{{x1,xl1,xc1,xe1,xn1}/.output,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"2",MapThread[Divide,{{x2,xl2,xc2,xe2,xn2}/.output,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"3",MapThread[Divide,{{x3,xl3,xc3,xe3,xn3}/.output,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten,
		{"4",MapThread[Divide,{gg*{x3,xl3,xc3,xe3,xn3}/.output,{xUSA0,xlUSA0,xcUSA0,xeUSA0,xnUSA0}}]}//Flatten}
	,5],
	Alignment->Center,Spacings->{2,1},Frame->All,ItemStyle->"Text",Background->{{LightBlue,None},{Gray,LightGray,None}}];


(* ::Text:: *)
(*\[Copyright]2014 Llavador, Roemer, Silvestre*)
